==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Очистить всё</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Очистить всё</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Прикрепить</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Сейчас</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 минут назад</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>1% часов назад</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Вчера</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Очистить всё</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Очистить всё</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin</source>
        <translation>Прикрепить</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Сейчас</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 минут назад</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>1% часов назад</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Вчера</translation>
    </message>
</context>
</TS>
